==> payroll_ver_3.2.1.zip: payroll3/src/jp/mosp/workflow/vo/ManagerApprovalMenuVo.java <==
/*
 * MosP - Mind Open Source Project         http://www.mosp.jp/
 * Copyright (C) 1987-2009 MIND Co., Ltd.  http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.workflow.vo;

import java.util.Properties;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPMenuConst;
import jp.mosp.common.MosPVo;
import jp.mosp.common.dto.CmAspUserDto;
import jp.mosp.common.dto.CmUserDto;

public class ManagerApprovalMenuVo extends MosPVo {

	private static final long serialVersionUID = -7133962712130667772L;

	// tB[h
	private String[][] aryApprovalMenu ;

	/**
	 * RXgN^
	 * @param cfg
	 * @param msg
	 * @param nam
	 * @param cmd
	 * @param aspUser
	 * @param user
	 */
	public ManagerApprovalMenuVo(
			Properties cfg,
			Properties msg,
			Properties nam,
			String cmd,
			CmAspUserDto aspUser,
			CmUserDto user
	) {
		super(cfg, msg, nam, cmd, aspUser, user);
		setViewPath(getClassName());
		aryApprovalMenu = new String[0][0];
	}

	public void setSubTitle() {
		subTitle = MosPMenuConst.getManagerCmdArray()[1][1];
		aryMenu = new String[][] {
				{ CMD_MENU_MAMAGE, CommonConst.NAM_TO_MENU },
		};
	}

	/**
	 * tB[hݒ
	 * @param aryApprovalMenu	e폳Fj[{^z 
	 * @throws MospException
	 */
	public void setFields(String [][] aryApprovalMenu) {
		this.aryApprovalMenu = escapeArray(aryApprovalMenu.clone());
	}

	/**
	 * JavaScriptݒ
	 * @param cls 擾NX
	 * @throws IllegalAccessException
	 */
	@Override
	public String getDirectJs(Class cls) throws IllegalAccessException {
		StringBuffer sb = new StringBuffer();
		sb.append(super.getDirectJs(cls));
		return sb.toString();
	}

	// ANZT\bh
	public String[][] getEscAryApprovalMenu() {
		return aryApprovalMenu.clone();
	}

}

==> payroll_ver_3.3.0.zip: payroll3/src/jp/mosp/workflow/vo/ManagerApprovalMenuVo.java <==
/*
 * MosP - Mind Open Source Project    http://www.mosp.jp/
 * Copyright (C) MIND Co., Ltd.       http://www.e-mind.co.jp/
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
package jp.mosp.workflow.vo;

import jp.mosp.common.CommonConst;
import jp.mosp.common.MosPMenuConst;
import jp.mosp.common.MosPVo;

/**
 * @author yoshida
 *
 */
public class ManagerApprovalMenuVo extends MosPVo {
	
	private static final long	serialVersionUID	= -7133962712130667772L;
	
	// tB[h
	private String[][]			aryApprovalMenu;
	

	/**
	 * RXgN^
	 */
	public ManagerApprovalMenuVo() {
		super();
		setViewPath(getClassName());
		aryApprovalMenu = new String[0][0];
	}
	
	@Override
	public void setSubTitle() {
		subTitle = MosPMenuConst.getMenuManagerApproval()[1];
		aryMenu = new String[][]{ { CMD_MENU_MAMAGE, CommonConst.NAM_TO_MENU }, };
	}
	
	/**
	 * tB[hݒ
	 * @param aryApprovalMenu	e폳Fj[{^z 
	 */
	public void setFields(String[][] aryApprovalMenu) {
		this.aryApprovalMenu = escapeArray(aryApprovalMenu.clone());
	}
	
	// ANZT\bh
	/**
	 * @return aryApprovalMenu
	 */
	public String[][] getEscAryApprovalMenu() {
		return aryApprovalMenu.clone();
	}
	
}
